@@ -105,31 +105,24 @@ fn impls_for_trait_item(
 #[cfg(test)]
 mod tests {
     use ide_db::base_db::FileRange;
+    use itertools::Itertools;
 
     use crate::fixture;
 
     fn check(ra_fixture: &str) {
-        let (analysis, position, annotations) = fixture::annotations(ra_fixture);
+        let (analysis, position, expected) = fixture::annotations(ra_fixture);
 
         let navs = analysis.goto_implementation(position).unwrap().unwrap().info;
 
-        let key = |frange: &FileRange| (frange.file_id, frange.range.start());
+        let cmp = |frange: &FileRange| (frange.file_id, frange.range.start());
 
-        let mut expected = annotations
-            .into_iter()
-            .map(|(range, data)| {
-                assert!(data.is_empty());
-                range
-            })
-            .collect::<Vec<_>>();
-        expected.sort_by_key(key);
-
-        let mut actual = navs
+        let actual = navs
             .into_iter()
             .map(|nav| FileRange { file_id: nav.file_id, range: nav.focus_or_full_range() })
+            .sorted_by_key(cmp)
             .collect::<Vec<_>>();
-        actual.sort_by_key(key);
-
+        let expected =
+            expected.into_iter().map(|(range, _)| range).sorted_by_key(cmp).collect::<Vec<_>>();
         assert_eq!(expected, actual);
     }
 
